@@ -42,7 +42,7 @@ int main(void)
     Display *dpy;
     Bool ret;
     int event_base, error_base;
-    int num_screens, num_gpus, num_framelocks, i;
+    int num_screens, num_gpus, num_framelocks, num_vcscs, i;
     int sources;
     XEvent event;
     XNVCtrlAttributeChangedEvent *nvevent;
@@ -101,6 +101,17 @@ int main(void)
         return 1;
     }
 
+    /* Query number of VCSC (Visual Computing System Controllers) devices */
+
+    ret = XNVCTRLQueryTargetCount(dpy, NV_CTRL_TARGET_TYPE_VCSC,
+                                  &num_vcscs);
+    if (ret != True) {
+        fprintf(stderr, "Failed to query the number of Visual Computing "
+                "System Controllers devices on '%s'.\n",
+                XDisplayName(NULL));
+        return 1;
+    }
+
     /*
      * register to receive NV-CONTROL events: whenever any NV-CONTROL
      * attribute is changed by an NV-CONTROL client, any other client
@@ -217,6 +228,24 @@ int main(void)
         sources++;
     }
 
+    /* Register to receive on all VCSC targets */
+
+    for (i = 0; i < num_vcscs; i++ ) {
+
+        ret = XNVCtrlSelectTargetNotify(dpy, NV_CTRL_TARGET_TYPE_VCSC,
+                                        i, TARGET_ATTRIBUTE_CHANGED_EVENT,
+                                        True);
+        if (ret != True) {
+            printf("- Unable to register to receive NV-CONTROL VCSC "
+                   "target events for VCSC %d on '%s'.\n",
+                   i, XDisplayName(NULL));
+            continue;
+        }
+        
+        printf("+ Listening to TARGET_ATTRIBUTE_CHANGE_EVENTs on VCSC "
+               "%d.\n", i);
+        sources++;
+    }
 
     /* 
      * Report the number of sources (things that we have registered to
@@ -292,6 +321,7 @@ static const char *target2str(int n)
     case NV_CTRL_TARGET_TYPE_X_SCREEN:  return "X Screen"; break;
     case NV_CTRL_TARGET_TYPE_GPU:       return "GPU"; break;
     case NV_CTRL_TARGET_TYPE_FRAMELOCK: return "Frame Lock"; break;
+    case NV_CTRL_TARGET_TYPE_VCSC:      return "VCSC"; break;
     default:
         return "Unknown";
     }
@@ -315,12 +345,20 @@ static const char *attr2str(int n)
     case NV_CTRL_FSAA_MODE:                        return "fsaa mode"; break;
     case NV_CTRL_TEXTURE_SHARPEN:                  return "texture sharpen"; break;
     case NV_CTRL_EMULATE:                          return "OpenGL software emulation"; break;
+    case NV_CTRL_CONNECTED_DISPLAYS:               return "connected displays"; break;
+    case NV_CTRL_ENABLED_DISPLAYS:                 return "enabled displays"; break;
     case NV_CTRL_FRAMELOCK_MASTER:                 return "frame lock master"; break;
     case NV_CTRL_FRAMELOCK_POLARITY:               return "frame lock sync edge"; break;
     case NV_CTRL_FRAMELOCK_SYNC_DELAY:             return "frame lock sync delay"; break;
     case NV_CTRL_FRAMELOCK_SYNC_INTERVAL:          return "frame lock sync interval"; break;
+    case NV_CTRL_FRAMELOCK_PORT0_STATUS:           return "frame lock port 0 status"; break;
+    case NV_CTRL_FRAMELOCK_PORT1_STATUS:           return "frame lock port 1 status"; break;
+    case NV_CTRL_FRAMELOCK_HOUSE_STATUS:           return "frame lock house status"; break;
     case NV_CTRL_FRAMELOCK_SYNC:                   return "frame lock sync"; break;
+    case NV_CTRL_FRAMELOCK_SYNC_READY:             return "frame lock sync ready"; break;
+    case NV_CTRL_FRAMELOCK_STEREO_SYNC:            return "frame lock stereo sync"; break;
     case NV_CTRL_FRAMELOCK_TEST_SIGNAL:            return "frame lock test signal"; break;
+    case NV_CTRL_FRAMELOCK_ETHERNET_DETECTED:      return "frame lock ethernet detected"; break;
     case NV_CTRL_FRAMELOCK_VIDEO_MODE:             return "frame lock video mode"; break;
     case NV_CTRL_FORCE_GENERIC_CPU:                return "force generic cpu"; break;
     case NV_CTRL_OPENGL_AA_LINE_GAMMA:             return "opengl aa line gamma"; break;
@@ -350,12 +388,33 @@ static const char *attr2str(int n)
     case NV_CTRL_AMBIENT_TEMPERATURE:              return "ambient temperature"; break;
     case NV_CTRL_PBUFFER_SCANOUT_XID:              return "scanout pbuffer xid"; break;
 
-        /* XXX GVO stuff */
+    case NV_CTRL_GVO_SUPPORTED:                         return "x screen supports gvo"; break;
+    case NV_CTRL_GVO_SYNC_MODE:                         return "gvo sync mode"; break;
+    case NV_CTRL_GVO_SYNC_SOURCE:                       return "gvo sync source"; break;
+    case NV_CTRL_GVO_OUTPUT_VIDEO_FORMAT:               return "gvo output video format"; break;
+    case NV_CTRL_GVO_DISPLAY_X_SCREEN:                  return "gvo clone mode"; break;
+    case NV_CTRL_GVO_COMPOSITE_SYNC_INPUT_DETECTED:     return "gvo composite sync input is detected"; break;
+    case NV_CTRL_GVO_COMPOSITE_SYNC_INPUT_DETECT_MODE:  return "gvo composite sync input detect mode"; break;
+    case NV_CTRL_GVO_SDI_SYNC_INPUT_DETECTED:           return "gvo sync input detected"; break;
+    case NV_CTRL_GVO_VIDEO_OUTPUTS:                     return "gvo video outputs"; break;
+    case NV_CTRL_GVO_FIRMWARE_VERSION:                  return "gvo firmware version"; break;
+    case NV_CTRL_GVO_SYNC_DELAY_PIXELS:                 return "gvo sync delay pixels"; break;
+    case NV_CTRL_GVO_SYNC_DELAY_LINES:                  return "gvo sync delay lines"; break;
+    case NV_CTRL_GVO_INPUT_VIDEO_FORMAT_REACQUIRE:      return "gvo input video format reacquire"; break;
+    case NV_CTRL_GVO_GLX_LOCKED:                        return "gvo glx locked"; break;
+    case NV_CTRL_GVO_X_SCREEN_PAN_X:                    return "gvo x screen pan x"; break;
+    case NV_CTRL_GVO_X_SCREEN_PAN_Y:                    return "gvo x screen pan y"; break;
+    case NV_CTRL_GVO_OVERRIDE_HW_CSC:                   return "gvo override hw csc"; break;
+    case NV_CTRL_GVO_CAPABILITIES:                      return "gvo capabilities"; break;
+    case NV_CTRL_GVO_COMPOSITE_TERMINATION:             return "gvo composite termination"; break;
+    case NV_CTRL_GVO_FLIP_QUEUE_SIZE:                   return "gvo flip queue size"; break;
+    case NV_CTRL_GVO_LOCK_OWNER:                        return "gvo lock owner"; break;
         
     case NV_CTRL_GPU_OVERCLOCKING_STATE:           return "overclocking state"; break;
     case NV_CTRL_GPU_2D_CLOCK_FREQS:               return "gpu 2d clock frequencies"; break;
     case NV_CTRL_GPU_3D_CLOCK_FREQS:               return "gpu 3d clock frequencies"; break;
     case NV_CTRL_GPU_OPTIMAL_CLOCK_FREQS:          return "gpu optimal clock frequencies"; break;
+    case NV_CTRL_GPU_OPTIMAL_CLOCK_FREQS_DETECTION: return "gpu optimal clock frequency detection"; break;
     case NV_CTRL_GPU_OPTIMAL_CLOCK_FREQS_DETECTION_STATE: return "gpu optimal clock frequency detection state"; break;
         
         /* XXX DDCCI stuff */
@@ -368,12 +427,34 @@ static const char *attr2str(int n)
     case NV_CTRL_SHOW_SLI_HUD:                     return "show sli hud"; break;
     case NV_CTRL_XV_SYNC_TO_DISPLAY:               return "xv sync to display"; break;
 
-        /* XXX More GVO stuff */
-
     case NV_CTRL_ASSOCIATED_DISPLAY_DEVICES:       return "associated_display_devices"; break;
     case NV_CTRL_FRAMELOCK_SLAVES:                 return "frame lock slaves"; break;
+    case NV_CTRL_FRAMELOCK_MASTERABLE:             return "frame lock masterable"; break;
     case NV_CTRL_PROBE_DISPLAYS:                   return "probed displays"; break;
 
+    case NV_CTRL_REFRESH_RATE:                     return "refresh rate"; break;
+    case NV_CTRL_CURRENT_SCANLINE:                 return "current scanline"; break;
+    case NV_CTRL_INITIAL_PIXMAP_PLACEMENT:         return "initial pixmap placement"; break;
+    case NV_CTRL_GLYPH_CACHE:                      return "glyph cache"; break;
+    case NV_CTRL_PCI_BUS:                          return "pci bus"; break;
+    case NV_CTRL_PCI_DEVICE:                       return "pci device"; break;
+    case NV_CTRL_PCI_FUNCTION:                     return "pci function"; break;
+    case NV_CTRL_FRAMELOCK_FPGA_REVISION:          return "framelock fpga revision"; break;
+    case NV_CTRL_MAX_SCREEN_WIDTH:                 return "max screen width"; break;
+    case NV_CTRL_MAX_SCREEN_HEIGHT:                return "max screen height"; break;
+    case NV_CTRL_MAX_DISPLAYS:                     return "max displays"; break;
+    case NV_CTRL_DYNAMIC_TWINVIEW:                 return "dynamic twinview"; break;
+    case NV_CTRL_MULTIGPU_DISPLAY_OWNER:           return "multigpu display owner"; break;
+    case NV_CTRL_GPU_SCALING:                      return "gpu scaling"; break;
+    case NV_CTRL_FRONTEND_RESOLUTION:              return "frontend resolution"; break;
+    case NV_CTRL_BACKEND_RESOLUTION:               return "backend resolution"; break;
+    case NV_CTRL_FLATPANEL_NATIVE_RESOLUTION:      return "flatpanel native resolution"; break;
+    case NV_CTRL_FLATPANEL_BEST_FIT_RESOLUTION:    return "flatpanel best fit resolution"; break;
+    case NV_CTRL_GPU_SCALING_ACTIVE:               return "gpu scaling active"; break;
+    case NV_CTRL_DFP_SCALING_ACTIVE:               return "dfp scaling active"; break;
+    case NV_CTRL_FSAA_APPLICATION_ENHANCED:        return "fsaa application enhanced"; break;
+    case NV_CTRL_FRAMELOCK_SYNC_RATE_4:            return "framelock sync rate (4)"; break;
+
     default:
         return "Unknown";
     }
