@@ -66,10 +66,13 @@ typedef struct _CtkDisplayConfig
     GtkWidget *obj_layout;
 
     GtkWidget *chk_xinerama_enabled;
+    GtkWidget *chk_primary_display;
+
+    GtkWidget *notebook; /* Tabbed notebook for display and X screen pages */
 
 
     /* Display - Info */
-    GtkWidget *display_frame;
+    GtkWidget *display_page;
 
     GtkWidget *txt_display_model;
     GtkWidget *txt_display_gpu;
@@ -102,7 +105,7 @@ typedef struct _CtkDisplayConfig
 
 
     /* X Screen - Info */
-    GtkWidget *screen_frame;
+    GtkWidget *screen_page;
 
     GtkWidget *txt_screen_num;
 
