@@ -28,6 +28,7 @@
 #include "NvCtrlAttributes.h"
 #include "ctkconfig.h"
 #include "ctkevent.h"
+#include "ctkgvo-banner.h"
 
 G_BEGIN_DECLS
 
@@ -54,30 +55,6 @@ G_BEGIN_DECLS
 typedef struct _CtkGvo       CtkGvo;
 typedef struct _CtkGvoClass  CtkGvoClass;
 
-typedef struct _CtkGvoBanner CtkGvoBanner;
-
-
-struct _CtkGvoBanner
-{
-    GtkWidget *table;
-    
-    GtkWidget *slots[4];
-
-    struct {
-        guint8 vid1;
-        guint8 vid2;
-        guint8 sdi;
-        guint8 comp;
-    } img;
-
-    struct {
-        guint8 vid1;
-        guint8 vid2;
-        guint8 sdi;
-        guint8 comp;
-    } state;
-};
-
 
 struct _CtkGvo
 {
@@ -87,47 +64,60 @@ struct _CtkGvo
     GtkWidget *parent_window;
     CtkConfig *ctk_config;
     CtkEvent *ctk_event;
+    
+    /* State */
 
-    GtkWidget *banner_frame;
+    gint caps; // Capabilities
 
-    GtkWidget *sync_mode_menu;
-    GtkWidget *output_video_format_menu;
-    GtkWidget *output_data_format_menu;
+    gint lock_owner;
 
-    GtkWidget *enable_sdi_output_label;
-    GtkWidget *disable_sdi_output_label;
-    GtkWidget *toggle_sdi_output_button;
+    gint sync_mode;
+    gint input_video_format;
+
+    gint output_video_format;
+    gint valid_output_video_format_mask[2];
+    gboolean has_output_video_formats;      // XXX Show show non-valid as gray?
+    gboolean output_video_format_invalid; /* If the output video format was
+                                             changed by another client to
+                                             something clone mode doesn't
+                                             support, we should ignore it,
+                                             but we should make sure that we
+                                             set the output_video_format when
+                                             we enable clone mode. */
+
+
+    gint output_data_format;
+    gboolean output_data_format_invalid; /* If the output data format was
+                                            changed by another client to
+                                            something clone mode doesn't
+                                            support, we should ignore it,
+                                            but we should make sure that we
+                                            set the output_data_format when
+                                            we enable clone mode. */
+
+    gint screen_width;
+    gint screen_height;
+
+    /* Widgets */
+
+    GtkWidget *banner_box;
+    GtkWidget *banner;
 
-    GtkWidget *sync_format_menu;
-    GtkWidget *input_video_format_text_entry;
-    GtkWidget *input_video_format_detect_button;
 
     GtkWidget *current_resolution_label;
     GtkWidget *current_state_label;
-    
-    gint sync_mode;
-    gint sync_source;
-    gint input_video_format;
-    gint output_video_format;
-    gint output_data_format;
 
-    gint valid_putput_video_format_mask;
-    gint input_video_format_detect_timer;
+    GtkWidget *clone_mode_frame;
 
-    GdkCursor *wait_cursor;
-    CtkGvoBanner banner;
-
-    GtkWidget *hsync_delay_spin_button;
-    GtkWidget *vsync_delay_spin_button;
+    GtkWidget *output_video_format_menu;
+    GtkWidget *output_data_format_menu;
 
     GtkWidget *x_offset_spin_button;
     GtkWidget *y_offset_spin_button;
 
-    gboolean sync_format_sensitive;
-    gboolean sdi_output_enabled;
-
-    gint screen_width;
-    gint screen_height;
+    GtkWidget *toggle_clone_mode_button;
+    GtkWidget *enable_clone_mode_label;
+    GtkWidget *disable_clone_mode_label;
 };
 
 
@@ -137,12 +127,34 @@ struct _CtkGvoClass
 };
 
 
+typedef struct {
+    int format;
+    const char *name;
+} GvoFormatName;
+
+typedef struct {
+    int format;
+    int rate;
+    int width;
+    int height;
+} GvoFormatDetails;
+
+
+
 GType          ctk_gvo_get_type    (void) G_GNUC_CONST;
 GtkWidget*     ctk_gvo_new         (NvCtrlAttributeHandle *,
-                                    GtkWidget *, CtkConfig *, CtkEvent *);
+                                    CtkConfig *, CtkEvent *);
 void           ctk_gvo_select      (GtkWidget *);
 void           ctk_gvo_unselect    (GtkWidget *);
 GtkTextBuffer* ctk_gvo_create_help (GtkTextTagTable *);
+void           ctk_gvo_pack_banner_slot (CtkGvoBanner *, gint slot, gint new);
+gint           ctk_gvo_probe       (gpointer data);
+
+
+
+const char *ctk_gvo_get_video_format_name(const gint format);
+const char *ctk_gvo_get_data_format_name(const gint format);
+void ctk_gvo_get_video_format_resolution(const gint format, gint *w, gint *h);
 
 
 G_END_DECLS
