@@ -38,6 +38,7 @@
 
 #include "ctkframelock.h"
 #include "ctkgvo.h"
+#include "ctkgvo-sync.h"
 #include "ctkgvo-csc.h"
 #include "ctkconfig.h"
 
@@ -256,7 +257,6 @@ static void tree_selection_changed(GtkTreeSelection *selection,
     GtkTreeIter iter;
     CtkWindow *ctk_window = CTK_WINDOW(user_data);
     GtkTreeModel *model = GTK_TREE_MODEL(ctk_window->tree_store);
-    gchar *str;
     GtkWidget *widget;
     GtkTextBuffer *help;
 
@@ -266,7 +266,6 @@ static void tree_selection_changed(GtkTreeSelection *selection,
     if (!gtk_tree_selection_get_selected(selection, &model, &iter))
         return;
 
-    gtk_tree_model_get(model, &iter, CTK_WINDOW_LABEL_COLUMN, &str, -1);
     gtk_tree_model_get(model, &iter, CTK_WINDOW_WIDGET_COLUMN, &widget, -1);
     gtk_tree_model_get(model, &iter, CTK_WINDOW_HELP_COLUMN, &help, -1);
     gtk_tree_model_get(model, &iter, CTK_WINDOW_SELECT_WIDGET_FUNC_COLUMN,
@@ -704,10 +703,10 @@ GtkWidget *ctk_window_new(NvCtrlAttributeHandle **screen_handles,
                      "Antialiasing Settings", NULL, NULL, NULL);
         }
 
+
         /* gvo (Graphics To Video Out) */
         
-        child = ctk_gvo_new(screen_handle, GTK_WIDGET(ctk_window),
-                            ctk_config, ctk_event);
+        child = ctk_gvo_new(screen_handle, ctk_config, ctk_event);
         if (child) {
             GtkWidget *gvo_parent = child;
             GtkTreeIter child_iter;
@@ -716,12 +715,26 @@ GtkWidget *ctk_window_new(NvCtrlAttributeHandle **screen_handles,
                      "Graphics to Video Out", NULL,
                      ctk_gvo_select, ctk_gvo_unselect);
 
-            /* add GVO sub-pages */
+            /* GVO Sync options */
+
+            child = ctk_gvo_sync_new(screen_handle,  GTK_WIDGET(ctk_window),
+                                     ctk_config, ctk_event,
+                                     CTK_GVO(gvo_parent));
+            if (child) {
+                help = ctk_gvo_sync_create_help(tag_table,
+                                                CTK_GVO_SYNC(child));
+                add_page(child, help, ctk_window, &child_iter, NULL,
+                         "Synchronization Options", NULL,
+                         ctk_gvo_sync_select, ctk_gvo_sync_unselect);
+            }
+
+            /* GVO color space conversion */
 
             child = ctk_gvo_csc_new(screen_handle, ctk_config, ctk_event,
                                     CTK_GVO(gvo_parent));
             if (child) {
-                add_page(child, NULL, ctk_window, &child_iter, NULL,
+                help = ctk_gvo_csc_create_help(tag_table, CTK_GVO_CSC(child));
+                add_page(child, help, ctk_window, &child_iter, NULL,
                          "Color Space Conversion", NULL,
                          ctk_gvo_csc_select, ctk_gvo_csc_unselect);
             }
