@@ -62,6 +62,7 @@ static char *nv_strndup(char *s, int n);
 #define H NV_PARSER_TYPE_100Hz
 #define K NV_PARSER_TYPE_1000Hz
 #define S NV_PARSER_TYPE_STRING_ATTRIBUTE
+#define I NV_PARSER_TYPE_SDI
 
 AttributeTableEntry attributeTable[] = {
    
@@ -106,6 +107,7 @@ AttributeTableEntry attributeTable[] = {
     { "RefreshRate",           NV_CTRL_REFRESH_RATE,                N|H   },
     { "RefreshRate3",          NV_CTRL_REFRESH_RATE_3,              N|K   },
     { "InitialPixmapPlacement",NV_CTRL_INITIAL_PIXMAP_PLACEMENT,    N     },
+    { "GlyphCache",            NV_CTRL_GLYPH_CACHE,                 N     },
     { "PCIBus",                NV_CTRL_PCI_BUS,                     N     },
     { "PCIDevice",             NV_CTRL_PCI_DEVICE,                  N     },
     { "PCIFunc",               NV_CTRL_PCI_FUNCTION,                N     },
@@ -119,6 +121,7 @@ AttributeTableEntry attributeTable[] = {
     { "GPUScalingActive",      NV_CTRL_GPU_SCALING_ACTIVE,          N     },
     { "DFPScalingActive",      NV_CTRL_DFP_SCALING_ACTIVE,          N     },
     { "FSAAAppEnhanced",       NV_CTRL_FSAA_APPLICATION_ENHANCED,   0     },
+    { "GPUErrors",             NV_CTRL_NUM_GPU_ERRORS_RECOVERED,    N     },
     { "OnDemandVBlankInterrupts", NV_CTRL_ONDEMAND_VBLANK_INTERRUPTS, 0   },
 
     { "FrameLockMaster",       NV_CTRL_FRAMELOCK_MASTER,            N|F|G|D },
@@ -143,28 +146,34 @@ AttributeTableEntry attributeTable[] = {
     { "FrameLockMasterable",   NV_CTRL_FRAMELOCK_MASTERABLE,        N|F|G },
     { "FrameLockFPGARevision", NV_CTRL_FRAMELOCK_FPGA_REVISION,     N|F|G },
 
-    { "GvoSupported",                    NV_CTRL_GVO_SUPPORTED,                        N },
-    { "GvoSyncMode",                     NV_CTRL_GVO_SYNC_MODE,                        N },
-    { "GvoSyncSource",                   NV_CTRL_GVO_SYNC_SOURCE,                      N },
-    { "GvoOutputVideoFormat",            NV_CTRL_GVO_OUTPUT_VIDEO_FORMAT,              N },
-    { "GvoInputVideoFormat",             NV_CTRL_GVO_INPUT_VIDEO_FORMAT,               N },
-    { "GvoDataFormat",                   NV_CTRL_GVO_DATA_FORMAT,                      N },
-    { "GvoDisplayXScreen",               NV_CTRL_GVO_DISPLAY_X_SCREEN,                 N },
-    { "GvoCompositeSyncInputDetected",   NV_CTRL_GVO_COMPOSITE_SYNC_INPUT_DETECTED,    N },
-    { "GvoCompositeSyncInputDetectMode", NV_CTRL_GVO_COMPOSITE_SYNC_INPUT_DETECT_MODE, N },
-    { "GvoSdiSyncInputDetected",         NV_CTRL_GVO_SDI_SYNC_INPUT_DETECTED,          N },
-    { "GvoVideoOutputs",                 NV_CTRL_GVO_VIDEO_OUTPUTS,                    N },
-    { "GvoSyncDelayPixels",              NV_CTRL_GVO_SYNC_DELAY_PIXELS,                N },
-    { "GvoSyncDelayLines",               NV_CTRL_GVO_SYNC_DELAY_LINES,                 N },
-    { "GvoGlxLocked",                    NV_CTRL_GVO_GLX_LOCKED,                       N },
-    { "GvoXScreenPanX",                  NV_CTRL_GVO_X_SCREEN_PAN_X,                   N },
-    { "GvoXScreenPanY",                  NV_CTRL_GVO_X_SCREEN_PAN_Y,                   N },
-    { "GvoOverrideHwCsc",                NV_CTRL_GVO_OVERRIDE_HW_CSC,                  N },
-    { "GvoCapabilities",                 NV_CTRL_GVO_CAPABILITIES,                     N },
-    { "GvoCompositeTermination",         NV_CTRL_GVO_COMPOSITE_TERMINATION,            N },
-    { "GvoFlipQueueSize",                NV_CTRL_GVO_FLIP_QUEUE_SIZE,                  N },
-    { "GvoFirmwareVersion",              NV_CTRL_STRING_GVO_FIRMWARE_VERSION,          S|N },
-    { "GvoLockOwner",                    NV_CTRL_GVO_LOCK_OWNER,                       N },
+    { "GvoSupported",                    NV_CTRL_GVO_SUPPORTED,                        I|N },
+    { "GvoSyncMode",                     NV_CTRL_GVO_SYNC_MODE,                        I },
+    { "GvoSyncSource",                   NV_CTRL_GVO_SYNC_SOURCE,                      I },
+    { "GvoOutputVideoFormat",            NV_CTRL_GVO_OUTPUT_VIDEO_FORMAT,              I },
+    { "GvoInputVideoFormat",             NV_CTRL_GVO_INPUT_VIDEO_FORMAT,               I|N },
+    { "GvoDataFormat",                   NV_CTRL_GVO_DATA_FORMAT,                      I },
+    { "GvoDisplayXScreen",               NV_CTRL_GVO_DISPLAY_X_SCREEN,                 I|N },
+    { "GvoCompositeSyncInputDetected",   NV_CTRL_GVO_COMPOSITE_SYNC_INPUT_DETECTED,    I|N },
+    { "GvoCompositeSyncInputDetectMode", NV_CTRL_GVO_COMPOSITE_SYNC_INPUT_DETECT_MODE, I|N },
+    { "GvoSdiSyncInputDetected",         NV_CTRL_GVO_SDI_SYNC_INPUT_DETECTED,          I|N },
+    { "GvoVideoOutputs",                 NV_CTRL_GVO_VIDEO_OUTPUTS,                    I|N },
+    { "GvoSyncDelayPixels",              NV_CTRL_GVO_SYNC_DELAY_PIXELS,                I },
+    { "GvoSyncDelayLines",               NV_CTRL_GVO_SYNC_DELAY_LINES,                 I },
+    { "GvoGlxLocked",                    NV_CTRL_GVO_GLX_LOCKED,                       I|N },
+    { "GvoXScreenPanX",                  NV_CTRL_GVO_X_SCREEN_PAN_X,                   I },
+    { "GvoXScreenPanY",                  NV_CTRL_GVO_X_SCREEN_PAN_Y,                   I },
+    { "GvoOverrideHwCsc",                NV_CTRL_GVO_OVERRIDE_HW_CSC,                  I },
+    { "GvoCapabilities",                 NV_CTRL_GVO_CAPABILITIES,                     I|N },
+    { "GvoCompositeTermination",         NV_CTRL_GVO_COMPOSITE_TERMINATION,            I },
+    { "GvoFlipQueueSize",                NV_CTRL_GVO_FLIP_QUEUE_SIZE,                  I },
+    { "GvoFirmwareVersion",              NV_CTRL_STRING_GVO_FIRMWARE_VERSION,          I|S|N },
+    { "GvoLockOwner",                    NV_CTRL_GVO_LOCK_OWNER,                       I|N },
+    { "GvoOutputVideoLocked",            NV_CTRL_GVO_OUTPUT_VIDEO_LOCKED,              I|N },
+    { "GvoSyncLockStatus",               NV_CTRL_GVO_SYNC_LOCK_STATUS,                 I|N },
+    { "GvoANCTimeCodeGeneration",        NV_CTRL_GVO_ANC_TIME_CODE_GENERATION,         I },
+    { "GvoComposite",                    NV_CTRL_GVO_COMPOSITE,                        I },
+    { "GvoCompositeAlphaKey",            NV_CTRL_GVO_COMPOSITE_ALPHA_KEY,              I },
+    { "GvoCompositeNumKeyRanges",        NV_CTRL_GVO_COMPOSITE_NUM_KEY_RANGES,         I|N },
 
     { "Brightness",            BRIGHTNESS_VALUE|ALL_CHANNELS,       N|C|G },
     { "RedBrightness",         BRIGHTNESS_VALUE|RED_CHANNEL,        C|G   },
@@ -230,6 +239,7 @@ AttributeTableEntry attributeTable[] = {
 #undef H
 #undef K
 #undef S
+#undef I
 
 /*
  * When new integer attributes are added to NVCtrl.h, an entry should
@@ -238,7 +248,7 @@ AttributeTableEntry attributeTable[] = {
  * about.
  */
 
-#if NV_CTRL_LAST_ATTRIBUTE != NV_CTRL_ONDEMAND_VBLANK_INTERRUPTS
+#if NV_CTRL_LAST_ATTRIBUTE != NV_CTRL_GVO_COMPOSITE_NUM_KEY_RANGES
 #warning "Have you forgotten to add a new integer attribute to attributeTable?"
 #endif
 
