@@ -1701,7 +1701,7 @@ int nv_process_parsed_attribute(ParsedAttribute *a, CtrlHandles *h,
             status = NvCtrlGetAttribute(t->h, NV_CTRL_FRAMELOCK, &available);
             if (status != NvCtrlSuccess) {
                 nv_error_msg("The attribute '%s' specified %s cannot be "
-                             "%s;  error querying frame lock availablity on "
+                             "%s; error querying frame lock availablity on "
                              "%s (%s).",
                              a->name, whence, assign ? "assigned" : "queried",
                              t->name, NvCtrlAttributesStrError(status));
@@ -1709,7 +1709,7 @@ int nv_process_parsed_attribute(ParsedAttribute *a, CtrlHandles *h,
             }
                 
             if (available != NV_CTRL_FRAMELOCK_SUPPORTED) {
-                nv_error_msg("The attribute '%s' specified %s cannot be %s;  "
+                nv_error_msg("The attribute '%s' specified %s cannot be %s; "
                              "frame lock is not supported/available on %s.",
                              a->name, whence, assign ? "assigned" : "queried",
                              t->name);
@@ -1725,7 +1725,7 @@ int nv_process_parsed_attribute(ParsedAttribute *a, CtrlHandles *h,
                                             &enabled);
                 if (status != NvCtrlSuccess) {
                     nv_error_msg("The attribute '%s' specified %s cannot be "
-                                 "assigned;  error querying frame lock sync "
+                                 "assigned; error querying frame lock sync "
                                  "status on %s (%s).",
                                  a->name, whence, t->name,
                                  NvCtrlAttributesStrError(status));
@@ -1735,14 +1735,14 @@ int nv_process_parsed_attribute(ParsedAttribute *a, CtrlHandles *h,
                 if (a->attr == NV_CTRL_FRAMELOCK_TEST_SIGNAL) {
                     if (enabled != NV_CTRL_FRAMELOCK_SYNC_ENABLE) {
                         nv_error_msg("The attribute '%s' specified %s cannot "
-                                     "be assigned;  frame lock sync is "
+                                     "be assigned; frame lock sync is "
                                      "currently disabled on %s.",
                                      a->name, whence, t->name);
                         continue;
                     }
                 } else if (enabled != NV_CTRL_FRAMELOCK_SYNC_DISABLE) {
                     nv_warning_msg("The attribute '%s' specified %s cannot be "
-                                   "assigned;  frame lock sync is currently "
+                                   "assigned; frame lock sync is currently "
                                    "enabled on %s.",
                                    a->name, whence, t->name);
                     continue;
@@ -1750,6 +1750,34 @@ int nv_process_parsed_attribute(ParsedAttribute *a, CtrlHandles *h,
             }
         }
 
+        /*
+         * To properly handle SDI (GVO) attributes, we just need to make
+         * sure that GVO is supported by the handle.
+         */
+
+        if (a->flags & NV_PARSER_TYPE_SDI) {
+            int available;
+
+            status = NvCtrlGetAttribute(t->h, NV_CTRL_GVO_SUPPORTED,
+                                        &available);
+            if (status != NvCtrlSuccess) {
+                nv_error_msg("The attribute '%s' specified %s cannot be "
+                             "%s; error querying SDI availablity on "
+                             "%s (%s).",
+                             a->name, whence, assign ? "assigned" : "queried",
+                             t->name, NvCtrlAttributesStrError(status));
+                continue;
+            }
+
+            if (available != NV_CTRL_GVO_SUPPORTED_TRUE) {
+                nv_error_msg("The attribute '%s' specified %s cannot be %s; "
+                             "SDI is not supported/available on %s.",
+                             a->name, whence, assign ? "assigned" : "queried",
+                             t->name);
+                continue;
+            }
+        }
+
         /* loop over the display devices */
 
         for (bit = 0; bit < 24; bit++) {
